package com.hack23.cia.service.user.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.math.BigDecimal;

import org.apache.cxf.jaxws.JaxWsProxyFactoryBean;
import org.apache.cxf.tools.common.DataTypeAdapter;
import org.hisrc.hifaces20.testing.webappenvironment.WebAppEnvironment;
import org.hisrc.hifaces20.testing.webappenvironment.annotations.PropertiesWebAppEnvironmentConfig;
import org.hisrc.hifaces20.testing.webappenvironment.testing.junit4.WebAppEnvironmentRule;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.MethodRule;

import com.hack23.cia.model.user.api.User;
import com.hack23.cia.model.user.api.UserType;
import com.hack23.cia.service.user.api.UserService;

public class UserServiceIT {

	@Rule
	public MethodRule webAppEnvironmentRule = WebAppEnvironmentRule.INSTANCE;

	@PropertiesWebAppEnvironmentConfig("src/test/resources/test-web.properties")
	public WebAppEnvironment webAppEnvironment;

	@Test
	public void checkUserService() throws Exception {

		final JaxWsProxyFactoryBean jaxWsProxyFactoryBean = new JaxWsProxyFactoryBean();
		jaxWsProxyFactoryBean.setServiceClass(UserService.class);
		jaxWsProxyFactoryBean.setAddress(webAppEnvironment.getBaseUrl()
				+ "/webservice/UserServicePort");

		final UserService customerService = (UserService) jaxWsProxyFactoryBean
				.create();

		final User originalUser = new User();

		// originalUser.setUserId(1);
		originalUser.setName("Scott Tiger");
		originalUser.getAddress().add("Hauptstr. 6");
		originalUser.getAddress().add("76133 Karlsruhe");
		originalUser.getAddress().add("Germany");
		originalUser.setNumOrders(15);
		originalUser.setRevenue(1234.56);
		originalUser.setTest(BigDecimal.valueOf(7890));
		originalUser.setBirthDate(DataTypeAdapter.parseDate("1970-01-01"));
		originalUser.setType(UserType.BUSINESS);

		final Integer customerId = customerService
				.updateUser(originalUser);

		assertNotNull(customerId);

		final User retrievedUser = customerService
				.getUserById(customerId);

		assertEquals(originalUser.getName(), retrievedUser.getName());
		assertEquals(originalUser.getAddress(), retrievedUser
				.getAddress());

		customerService.deleteUserById(retrievedUser.getModelObjectId());

	}
}
